@@ -13,12 +13,12 @@ import yaml
 from apispec import APISpec, yaml_utils
 from apispec.ext.marshmallow import MarshmallowPlugin
 from asgiref.wsgi import WsgiToAsgi
-from starlette.debug import DebugMiddleware
 from starlette.exceptions import ExceptionMiddleware
 from starlette.lifespan import LifespanHandler
 from starlette.middleware.cors import CORSMiddleware
 from starlette.middleware.gzip import GZipMiddleware
 from starlette.middleware.httpsredirect import HTTPSRedirectMiddleware
+from starlette.middleware.trustedhost import TrustedHostMiddleware
 from starlette.routing import Router
 from starlette.staticfiles import StaticFiles
 from starlette.testclient import TestClient
@@ -26,7 +26,6 @@ from starlette.websockets import WebSocket
 from whitenoise import WhiteNoise
 
 from . import models, status_codes
-from .middlewares.trustedhost import TrustedHostMiddleware
 from .background import BackgroundQueue
 from .formats import get_formats
 from .routes import Route
@@ -67,7 +66,8 @@ class API:
         enable_hsts=False,
         docs_route=None,
         cors=False,
-        allowed_hosts=None
+        cors_params=DEFAULT_CORS_PARAMS,
+        allowed_hosts=None,
     ):
         self.background = BackgroundQueue()
 
@@ -89,7 +89,7 @@ class API:
 
         self.hsts_enabled = enable_hsts
         self.cors = cors
-        self.cors_params = DEFAULT_CORS_PARAMS
+        self.cors_params = cors_params
 
         if not allowed_hosts:
             # if not debug:
@@ -129,14 +129,12 @@ class API:
         self.default_endpoint = None
         self.app = self.dispatch
         self.add_middleware(GZipMiddleware)
-        if debug:
-            self.add_middleware(DebugMiddleware)
 
         if self.hsts_enabled:
             self.add_middleware(HTTPSRedirectMiddleware)
-        
+
         self.add_middleware(TrustedHostMiddleware, allowed_hosts=self.allowed_hosts)
-    
+
         self.lifespan_handler = LifespanHandler()
 
         if self.cors:
@@ -183,10 +181,10 @@ class API:
                 operations = yaml_utils.load_operations_from_docstring(
                     self.routes[route].description
                 )
-                spec.add_path(path=route, operations=operations)
+                spec.path(path=route, operations=operations)
 
         for name, schema in self.schemas.items():
-            spec.definition(name, schema=schema)
+            spec.components.schema(name, schema=schema)
 
         return spec
 
@@ -293,7 +291,6 @@ class API:
         # Get the route.
         route = self.path_matches_route(req.url.path)
         route = self.routes.get(route)
-
         if route:
             if route.uses_websocket:
                 resp = WebSocket(**options)
@@ -352,7 +349,7 @@ class API:
                 if hasattr(r, "send"):
                     await r
             except Exception:
-                self.background(self.default_response, req, resp, error=True)
+                await self.background(self.default_response, req, resp, error=True)
                 raise
 
             # Then run on_method.
@@ -365,8 +362,8 @@ class API:
                 if hasattr(r, "send"):
                     await r
             except Exception as e:
-
-                self.background(self.default_response, req, resp, error=True)
+                await self.background(self.default_response, req, resp, error=True)
+                raise
 
     def add_event_handler(self, event_type, handler):
         """Adds an event handler to the API.
@@ -604,7 +601,7 @@ class API:
         template = self.jinja_env.from_string(s_)
         return template.render(**values)
 
-    def run(self, address=None, port=None, debug=False, **options):
+    def serve(self, *, address=None, port=None, debug=False, **options):
         """Runs the application with uvicorn. If the ``PORT`` environment
         variable is set, requests will be served on that port automatically to all
         known hosts.
@@ -629,3 +626,6 @@ class API:
             uvicorn.run(self, host=address, port=port, debug=debug, **options)
 
         spawn()
+
+    def run(self, **kwargs):
+        self.serve(**kwargs)
